@@ -6,18 +6,18 @@ from web_foundation.app.events.store import StoreUpdateEvent
 
 async def some_handler(context, container):
     loguru.logger.info("ASSSSSSSSSSSSSSSSSSSSSSSsss")
-    mg = container.plugin_manager()
-    await container.ticket_service().emmit_event(CloseChargeAeEvent())
-    # await container.ticket_service().emmit_event(StoreUpdateEvent("plugins", mg.available_plugins))
+    # await container.ticket_service().emmit_event(CloseChargeAeEvent())
+    # await container.ticket_service().emmit_event(StoreUpdateEvent("plugins", mg.plugs_to_send))
     return {}
 
 
 async def add_plugin(context, app_container):
-    mg = app_container.plugin_manager()
-    # await app_container.store().get_all()
-    await mg.add_new_plugin(context.request.json.get("filename"))
-    await app_container.ticket_service().emmit_event(StoreUpdateEvent("plugins", mg.available_plugins))
-    await app_container.ticket_service().emmit_event(CloseChargeAeEvent())
+    await app_container.ticket_service().worker.add_new_plugin(context.request.json.get("filename"))
+    # mg = app_container.plugin_manager()
+    # # await app_container.store().get_all()
+    # await mg.add_new_plugin(context.request.json.get("filename"))
+    # await app_container.ticket_service().emmit_event(StoreUpdateEvent("plugins", mg.available_plugins))
+    # await app_container.ticket_service().emmit_event(CloseChargeAeEvent())
     return {}
 
 
