@@ -1,12 +1,16 @@
 import inspect
 import re
+from copy import deepcopy
 from typing import Dict, Callable, Type
+
+import loguru
 from pydantic import BaseModel as PdModel
 
 import sanic_ext
 from sanic import Sanic
 from sanic_ext.extensions.openapi.builders import SpecificationBuilder, OperationStore
 
+from web_foundation.app.infrastructure.plugins.manager import PluginsManager
 from web_foundation.workers.io.http.routers.ext_router import ExtRouter, RouteMethodConf, RouteConf
 
 
@@ -36,9 +40,12 @@ def get_model_schema(model: Type[PdModel]):
 
 def add_openapi_spec(uri: str, method_name: str, func: Callable, handler: Callable,
                      in_dto: Type[PdModel], out_dto: Type[PdModel]):
+    # --- copy existed openapi params ---#
+    if OperationStore().get(func):
+        OperationStore()[handler] = deepcopy(OperationStore().get(func))
     # --- add query args ---#
     func_text = inspect.getsource(func)
-    func_query_args = re.findall(r"request.args.get\(\"(\w*)\"\)", func_text)
+    func_query_args = set(re.findall(r"request.args.get\(\"(\w*)\"\)", func_text))
     if func_query_args:
         for func_arg in func_query_args:
             handler = sanic_ext.openapi.parameter(func_arg)(handler)
@@ -51,7 +58,8 @@ def add_openapi_spec(uri: str, method_name: str, func: Callable, handler: Callab
     if out_dto:
         if issubclass(out_dto, PdModel):
             schema = get_model_schema(out_dto)
-            OperationStore()[handler].responses[200] = {"content": {"application/json": {'schema': schema}}}
+            OperationStore()[handler].responses[200] = {"content": {"application/json": {'schema': schema}},
+                                                        "description": "OK"}
     # --- add tag ---#
     handler = sanic_ext.openapi.tag(uri.split("/")[1].capitalize())(handler)  # first path word
 
@@ -67,10 +75,13 @@ def add_openapi_spec(uri: str, method_name: str, func: Callable, handler: Callab
 class DictRouter(ExtRouter):
     _router_conf: Dict
     chaining: Callable
+    plugin_manager: PluginsManager | None
     versioning: bool
 
-    def __init__(self, routes_config: Dict, chaining: Callable, versioning: bool = True):
+    def __init__(self, routes_config: Dict, chaining: Callable, plugin_manager: PluginsManager = None,
+                 versioning: bool = True):
         super().__init__()
+        self.plugin_manager = plugin_manager
         self.chaining = chaining
         self._router_conf = routes_config
         self.chains = []
@@ -100,10 +111,12 @@ class DictRouter(ExtRouter):
                             chain = self.chaining(
                                 protector=protector,
                                 in_struct=in_dto,
+                                plugin_manager=self.plugin_manager,
                                 response_fabric=response_fabric)(target_func)
                         else:
                             chain = self.chaining(
                                 protector=protector,
+                                plugin_manager=self.plugin_manager,
                                 in_struct=in_dto)(target_func)
 
                         chain = add_openapi_spec(uri=endpoint, method_name=method_name, func=target_func,
