@@ -31,7 +31,7 @@ class SseRtMessage(RtMessage):
         if self.data:
             buffer.write('data: ' + json.dumps(self.data))
         else:
-            buffer.write('data: ')
+            buffer.write('data: {}')
         buffer.write("\r\n\r\n")
         return buffer.getvalue()
 
