@@ -14,7 +14,7 @@ from sanic import Sanic
 from sanic.server.socket import bind_socket
 
 from web_foundation.app.app import AppContainer
-from web_foundation.app.events.store import StoreUpdateEvent
+from web_foundation.app.events.store import StoredPluginsUpdate
 from web_foundation.app.infrastructure.plugins.manager import PluginsManager
 from web_foundation.kernel import GenericIMessage, IMessage
 from web_foundation.workers.io.http.ext_error_handler import ExtendedErrorHandler
@@ -52,6 +52,8 @@ class HttpServer(Worker):
         self.rt_connections = []
         self._set_sanic_confs()
         self.plugin_manager = plugin_manager
+        self.plugin_manager.debug = self.debug
+        self.channel.add_event_listener(StoredPluginsUpdate, self.on_plugin_update_event)
         if self.router and issubclass(self.router.__class__, ExtRouter):
             self.router.apply_routes(self.sanic_app)
 
@@ -63,7 +65,7 @@ class HttpServer(Worker):
     async def _init_wrk(self, app):
         await self._init_resources()
         if self.plugin_manager:
-            await self.plugin_manager.init_all_plugins()
+            await self.plugin_manager.import_plugins()
 
     async def _run(self):
         self.sanic_app.register_listener(self._init_wrk, "before_server_start")
@@ -82,7 +84,7 @@ class HttpServer(Worker):
 
     def wire_worker(self, container: AppContainer) -> None:  # type: ignore
         if not self.router:
-            raise AttributeError(f"{self.__class__} has no attribute router")
+            raise AttributeError(f"{self.__class__} has no router")
         for chain in self.router.chains:
             for method in chain.methods:
                 if method.protector:
@@ -95,7 +97,17 @@ class HttpServer(Worker):
         sock.set_inheritable(True)
         return sock
 
-    async def on_event(self, message: GenericIMessage, resolve_callback: RtEventCallback = None):
+    async def on_plugin_update_event(self, event: StoredPluginsUpdate):
+        if self.name != event.sender:
+            await self.plugin_manager.reload_from_event(event.filename)
+
+    async def add_new_plugin(self, filename: str):
+        if not self.plugin_manager:
+            raise AttributeError("Worker has not attribute plugin_manager")
+        await self.plugin_manager.add_new_plugin(filename)
+        await self.channel.produce(StoredPluginsUpdate(filename))
+
+    async def on_rt_event(self, message: GenericIMessage, resolve_callback: RtEventCallback = None):
         await self.broadcast_rt_events(message, resolve_callback)
 
     async def broadcast_rt_events(self, event: GenericIMessage,
@@ -153,6 +165,5 @@ def subscribe_worker_rt_callback(*workers: HttpServer,
                                  callback: RtEventCallback,
                                  use_nested_classes: bool = False):
     for worker in workers:
-        worker.channel.add_event_listener(StoreUpdateEvent, worker.on_store_update)
-        worker.channel.add_event_listener(event_type, partial(worker.on_event, resolve_callback=callback),
+        worker.channel.add_event_listener(event_type, partial(worker.on_rt_event, resolve_callback=callback),
                                           use_nested_classes=use_nested_classes)
